@@ -8,4 +8,9 @@ try:
     def go_to_the_url(step, url):
         world.response = world.browser.visit(django_url(url))
 except:
-    logger.warn("Django steps not imported.")
+    try:
+        # Only complain if it seems likely that using django was intended.
+        import django
+        logger.warn("Django steps not imported.")
+    except:
+        pass
