@@ -4,9 +4,12 @@ from salad.logger import logger
 old_database_name = None
 
 try:
+    logger = getLogger(__name__)
+    logger.info("Loading the terrain file...")
+
     from django.core.management import call_command
     from django.conf import settings
-    from django.test.simple  import DjangoTestSuiteRunner
+    from django.test.simple import DjangoTestSuiteRunner
     from django.core import mail
     try:
         from south.management.commands import patch_for_test_db_setup
@@ -16,46 +19,38 @@ try:
 
     @before.runserver
     def setup_database(actual_server):
-        logger.info("Setting up a test database ...\n")
-
-        if settings.DATABASES["default"]["ENGINE"] != "django.db.backends.sqlite3":
-            from django.db import connection
-            global old_database_name
-            old_database_name = settings.DATABASES["default"]["NAME"]
-            connection.creation.create_test_db()
-        else:
-            # connection.settings_dict["NAME"] = ":memory:"
-            pass
+        logger.info("Setting up a test database...")
 
         if USE_SOUTH:
             patch_for_test_db_setup()
 
         world.test_runner = DjangoTestSuiteRunner(interactive=False)
-        world.test_runner.setup_test_environment()
+        DjangoTestSuiteRunner.setup_test_environment(world.test_runner)
+        world.created_db = DjangoTestSuiteRunner.setup_databases(world.test_runner)
 
         call_command('syncdb', interactive=False, verbosity=0)
-        call_command('flush', interactive=False, verbosity=0)
+        call_command('migrate', interactive=False, verbosity=0)
+        call_command('loaddata', 'all', verbosity=0)
 
     @after.runserver
     def teardown_database(actual_server):
-        logger.info("Destroying test database ...\n")
-        if hasattr(world, "test_runner"):
-            world.test_runner.teardown_test_environment()
-        if settings.DATABASES["default"]["ENGINE"] != "django.db.backends.sqlite3":
-            from django.db import connection
-            connection.creation.destroy_test_db(old_database_name)
+        logger.info("Destroying the test database ...")
 
-    @after.each_feature
+        DjangoTestSuiteRunner.teardown_databases(world.test_runner, world.created_db)
+        DjangoTestSuiteRunner.teardown_test_environment(world.test_runner)
+
+    @before.each_scenario
     def reset_data(scenario):
-        logger.info("Flushing...")
+        # Clean up django.
+        logger.info("Flushing the test database...")
         call_command('flush', interactive=False, verbosity=0)
+        call_command('loaddata', 'all', verbosity=0)
 
     @before.each_feature
     def empty_outbox(scenario):
         logger.info("Emptying outbox...")
         mail.outbox = []
 
-
 except:
     try:
         # Only complain if it seems likely that using django was intended.
